@@ -11,22 +11,18 @@
 ///
 /// The facter library minor version.
 ///
-#define LIBFACTER_VERSION_MINOR 0
+#define LIBFACTER_VERSION_MINOR 2
 ///
 /// The facter library patch version.
 ///
-#define LIBFACTER_VERSION_PATCH 2
-///
-/// The facter library Git SHA1.
-///
-#define LIBFACTER_GIT_SHA1 ""
+#define LIBFACTER_VERSION_PATCH 0
 
 ///
 /// The facter library version as a string (without commit SHA1).
 ///
-#define LIBFACTER_VERSION "3.0.2"
+#define LIBFACTER_VERSION "3.2.0"
 
 ///
 /// The facter library version as a string (with commit SHA1).
 ///
-#define LIBFACTER_VERSION_WITH_COMMIT "3.0.2"
+#define LIBFACTER_VERSION_WITH_COMMIT "3.2.0"
